@@ -1,9 +1,5 @@
 import enum
 
-class KerberosSocketType(enum.Enum):
-	UDP = enum.auto()
-	TCP = enum.auto()	
-
 class KerberosSecretType(enum.Enum):
 	PASSWORD = 'PASSWORD'
 	PW = 'PW'
@@ -20,4 +16,5 @@ class KerberosSecretType(enum.Enum):
 	KEYTAB = 'KEYTAB'
 	KIRBI = 'KIRBI'
 	PFX = 'PFX'
-	PEM = 'PEM'
\ No newline at end of file
+	PEM = 'PEM'
+	PFXSTR = 'PFXSTR'
\ No newline at end of file
